@@ -1,8 +1,9 @@
 # https://cran.r-project.org/doc/manuals/R-exts.html#Package-subdirectories
-execs <- c("gadget")
+execs <- c("../gadget")
 if(WINDOWS) execs <- paste0(execs, ".exe")
 if ( any(file.exists(execs)) ) {
   dest <- file.path(R_PACKAGE_DIR,  paste0('bin', R_ARCH))
   dir.create(dest, recursive = TRUE, showWarnings = FALSE)
   file.copy(execs, dest, overwrite = TRUE)
+  file.remove(execs)
 }
